@@ -553,10 +553,10 @@ class DataTransform(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         super(DataTransform, self).__init__(*args, **kwargs)
-        if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
+        if hasattr(self.instance, 'get_children') and self.instance.get_children() > 0:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                                  fk_name='parent', form=DataTransform,
-                                                                 extra=0
+                                                                 extra=self.instance.get_children() + 1
                                                                  )
             self.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=self.instance,
@@ -565,6 +565,8 @@ class DataTransform(forms.ModelForm):
                 initial=[{'parent': self.instance.id}]
             )
 
+        self.instance.get_children().count() + 1
+
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
             data=self.data if self.is_bound else None,
@@ -617,17 +619,16 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
-        if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
-            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                 fk_name='parent', form=DataTransform,
-                                                                 extra=1
-                                                                 )
-            self.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=self.instance,
-                data=self.data if self.is_bound else None,
-                files=self.files if self.is_bound else None,
-                initial=[{'parent': self.instance.id}]
-            )
+        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                             fk_name='parent', form=DataTransform,
+                                                             extra=self.instance.get_children().count() + 1
+                                                             )
+        self.nested_data_transformer_form = dataTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None,
+            initial=[{'parent': str(self.instance.id),}]
+        )
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
